@@ -1,21 +1,21 @@
 '''
 Implements the RTS generic Target fabric classes.
 
-This file is part of RTSLib Community Edition.
-Copyright (c) 2011-2013 by RisingTide Systems LLC
-Copyright (c) 2011-2012 by Red Hat, Inc.
+This file is part of RTSLib.
+Copyright (c) 2011-2013 by Datera, Inc.
+Copyright (c) 2011-2013 by Red Hat, Inc.
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, version 3 (AGPLv3).
+Licensed under the Apache License, Version 2.0 (the "License"); you may
+not use this file except in compliance with the License. You may obtain
+a copy of the License at
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+    http://www.apache.org/licenses/LICENSE-2.0
 
-You should have received a copy of the GNU Affero General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+License for the specific language governing permissions and limitations
+under the License.
 '''
 
 import re
@@ -29,7 +29,9 @@ from doctest import testmod
 from utils import RTSLibError, RTSLibBrokenLink, modprobe
 from utils import fread, fwrite, normalize_wwn, generate_wwn
 from utils import dict_remove, set_attributes, set_parameters, ignored
+from utils import _get_auth_attr, _set_auth_attr
 import tcm
+from functools import partial
 
 class Target(CFSNode):
     '''
@@ -465,6 +467,30 @@ class TPG(CFSNode):
     nexus = property(_get_nexus, _set_nexus,
                      doc="Get or set (once) the TPG's Nexus is used.")
 
+    chap_userid = property(partial(_get_auth_attr, attribute='auth/userid', ignore=True),
+                           partial(_set_auth_attr, attribute='auth/userid', ignore=True),
+                           doc="Set or get the initiator CHAP auth userid.")
+    chap_password = property(partial(_get_auth_attr, attribute='auth/password', ignore=True),
+                             partial(_set_auth_attr, attribute='auth/password', ignore=True),
+                             doc="Set or get the initiator CHAP auth password.")
+    chap_mutual_userid = property(partial(_get_auth_attr, attribute='auth/userid_mutual', ignore=True),
+                                  partial(_set_auth_attr, attribute='auth/userid_mutual', ignore=True),
+                                  doc="Set or get the initiator CHAP auth userid.")
+    chap_mutual_password = property(partial(_get_auth_attr, attribute='auth/password_mutual', ignore=True),
+                                    partial(_set_auth_attr, attribute='auth/password_mutual', ignore=True),
+                                    doc="Set or get the initiator CHAP auth password.")
+
+    def _get_authenticate_target(self):
+        self._check_self()
+        path = "%s/auth/authenticate_target" % self.path
+        try:
+            return bool(int(fread(path)))
+        except:
+            return None
+
+    authenticate_target = property(_get_authenticate_target,
+                                   doc="Get the boolean authenticate target flag.")
+
     def dump(self):
         d = super(TPG, self).dump()
         d['tag'] = self.tag
@@ -472,6 +498,11 @@ class TPG(CFSNode):
         d['luns'] = [lun.dump() for lun in self.luns]
         d['portals'] = [portal.dump() for portal in self.network_portals]
         d['node_acls'] =  [acl.dump() for acl in self.node_acls]
+        if self.has_feature("auth"):
+            for attr in ("userid", "password", "mutual_userid", "mutual_password"):
+                val = getattr(self, "chap_" + attr, None)
+                if val:
+                    d["chap_" + attr] = val
         return d
 
 
@@ -799,70 +830,6 @@ class NodeACL(CFSNode):
     def _get_parent_tpg(self):
         return self._parent_tpg
 
-    def _get_chap_mutual_password(self):
-        self._check_self()
-        path = "%s/auth/password_mutual" % self.path
-        value = fread(path)
-        if value == "NULL":
-            return ''
-        else:
-            return value
-
-    def _set_chap_mutual_password(self, password):
-        self._check_self()
-        path = "%s/auth/password_mutual" % self.path
-        if password.strip() == '':
-            password = "NULL"
-        fwrite(path, "%s" % password)
-
-    def _get_chap_mutual_userid(self):
-        self._check_self()
-        path = "%s/auth/userid_mutual" % self.path
-        value = fread(path)
-        if value == "NULL":
-            return ''
-        else:
-            return value
-
-    def _set_chap_mutual_userid(self, userid):
-        self._check_self()
-        path = "%s/auth/userid_mutual" % self.path
-        if userid.strip() == '':
-            userid = "NULL"
-        fwrite(path, "%s" % userid)
-
-    def _get_chap_password(self):
-        self._check_self()
-        path = "%s/auth/password" % self.path
-        value = fread(path)
-        if value == "NULL":
-            return ''
-        else:
-            return value
-
-    def _set_chap_password(self, password):
-        self._check_self()
-        path = "%s/auth/password" % self.path
-        if password.strip() == '':
-            password = "NULL"
-        fwrite(path, "%s" % password)
-
-    def _get_chap_userid(self):
-        self._check_self()
-        path = "%s/auth/userid" % self.path
-        value = fread(path)
-        if value == "NULL":
-            return ''
-        else:
-            return value
-
-    def _set_chap_userid(self, userid):
-        self._check_self()
-        path = "%s/auth/userid" % self.path
-        if userid.strip() == '':
-            userid = "NULL"
-        fwrite(path, "%s" % userid)
-
     def _get_tcq_depth(self):
         self._check_self()
         path = "%s/cmdsn_depth" % self.path
@@ -894,14 +861,6 @@ class NodeACL(CFSNode):
             else:
                 fwrite("%s/tag" % self.path, tag_str)
 
-    def _get_authenticate_target(self):
-        self._check_self()
-        path = "%s/auth/authenticate_target" % self.path
-        if fread(path) == "1":
-            return True
-        else:
-            return False
-
     def _list_mapped_luns(self):
         self._check_self()
         for mapped_lun_dir in glob("%s/lun_*" % self.path):
@@ -966,19 +925,6 @@ class NodeACL(CFSNode):
         return MappedLUN(self, mapped_lun=mapped_lun, tpg_lun=tpg_lun,
                          write_protect=write_protect)
 
-    chap_userid = property(_get_chap_userid, _set_chap_userid,
-                           doc="Set or get the initiator CHAP auth userid.")
-    chap_password = property(_get_chap_password, _set_chap_password,
-                             doc=\
-                             "Set or get the initiator CHAP auth password.")
-    chap_mutual_userid = property(_get_chap_mutual_userid,
-                                  _set_chap_mutual_userid,
-                                  doc=\
-                                  "Set or get the mutual CHAP auth userid.")
-    chap_mutual_password = property(_get_chap_mutual_password,
-                                    _set_chap_mutual_password,
-                                    doc=\
-                                    "Set or get the mutual CHAP password.")
     tcq_depth = property(_get_tcq_depth, _set_tcq_depth,
                          doc="Set or get the TCQ depth for the initiator " \
                          + "sessions matching this NodeACL.")
@@ -988,24 +934,43 @@ class NodeACL(CFSNode):
             doc="Get the parent TPG object.")
     node_wwn = property(_get_node_wwn,
             doc="Get the node wwn.")
-    authenticate_target = property(_get_authenticate_target,
-            doc="Get the boolean authenticate target flag.")
     mapped_luns = property(_list_mapped_luns,
             doc="Get the list of all MappedLUN objects in this NodeACL.")
     session = property(_get_session,
             doc="Gives a snapshot of the current session or C{None}")
 
+    chap_userid = property(partial(_get_auth_attr, attribute='auth/userid'),
+                           partial(_set_auth_attr, attribute='auth/userid'),
+                           doc="Set or get the initiator CHAP auth userid.")
+    chap_password = property(partial(_get_auth_attr, attribute='auth/password'),
+                             partial(_set_auth_attr, attribute='auth/password',),
+                             doc="Set or get the initiator CHAP auth password.")
+    chap_mutual_userid = property(partial(_get_auth_attr, attribute='auth/userid_mutual'),
+                                  partial(_set_auth_attr, attribute='auth/userid_mutual'),
+                                  doc="Set or get the initiator CHAP auth userid.")
+    chap_mutual_password = property(partial(_get_auth_attr, attribute='auth/password_mutual'),
+                                    partial(_set_auth_attr, attribute='auth/password_mutual'),
+                                    doc="Set or get the initiator CHAP auth password.")
+
+    def _get_authenticate_target(self):
+        self._check_self()
+        path = "%s/auth/authenticate_target" % self.path
+        return bool(int(fread(path)))
+
+    authenticate_target = property(_get_authenticate_target,
+                                   doc="Get the boolean authenticate target flag.")
+
     def dump(self):
         d = super(NodeACL, self).dump()
-        if self.has_feature("acls_auth"):
-            for attr in ("userid", "password", "mutual_userid", "mutual_password"):
-                val = getattr(self, "chap_" + attr, None)
-                if val:
-                    d["chap_" + attr] = val
         d['node_wwn'] = self.node_wwn
         d['mapped_luns'] = [lun.dump() for lun in self.mapped_luns]
         if self.tag:
             d['tag'] = self.tag
+        if self.has_feature("auth"):
+            for attr in ("userid", "password", "mutual_userid", "mutual_password"):
+                val = getattr(self, "chap_" + attr, None)
+                if val:
+                    d["chap_" + attr] = val
         return d
 
 
@@ -1135,11 +1100,7 @@ class MappedLUN(CFSNode):
     def _get_write_protect(self):
         self._check_self()
         path = "%s/write_protect" % self.path
-        write_protect = fread(path)
-        if write_protect == "1":
-            return True
-        else:
-            return False
+        return bool(int(fread(path)))
 
     def _get_tpg_lun(self):
         self._check_self()
